var bump = require('gulp-bump');
var fs = require('fs');
var git = require('gulp-git');
var gulp = require('gulp');
var spawn = require('child_process').spawn;
var yargs = require('yargs');


/**
 * Pulls the package json from fs
 */
var getPackageJson = function() {
    return JSON.parse(fs.readFileSync('./package.json', 'utf8'));
};



// Override the tab size for indenting
// (or simply omit to keep the current formatting)
gulp.task('bump', function() {
    gulp.src('./package.json')
        .pipe(bump({
            type: 'patch'
        }))
        .pipe(gulp.dest('./'));
});

// Run git add
// src is the file(s) to add (or ./*)
gulp.task('git-add', function() {
    return gulp.src('./*')
        .pipe(git.add());
});

// Run git commit
// src are the files to commit (or ./*)
gulp.task('git-commit', function() {
    return gulp.src('./git-test/*')
        .pipe(git.commit('initial commit'));
});

// Tag the repo with a version
gulp.task('git-tag', function() {
    var pkg = getPackageJson();
    git.tag('v' + pkg.version, 'Version message', function(err) {
        if (err) throw err;
    });
});


gulp.task('npm-publish', function(done) {
    spawn('npm', ['publish'], {
        stdio: 'inherit'
    }).on('close', done);
});

// Run git push
// remote is the remote repo
// branch is the remote branch to push to
gulp.task('git-push', function() {
    git.push('origin', 'master', function(err) {
        if (err) throw err;
    });
});

gulp.task('publish', ['bump', 'git-add', 'git-commit', 'git-tag', 'git-push', 'npm-publish']);
